package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthMedicalReportProject;
import com.bonus.canteen.core.health.service.IHealthMedicalReportProjectService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 体检报告项目Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "体检报告项目接口")
@RestController
@RequestMapping("/health_medical_report_project")
public class HealthMedicalReportProjectController extends BaseController {
    @Autowired
    private IHealthMedicalReportProjectService healthMedicalReportProjectService;

    /**
     * 查询体检报告项目列表
     */
    @ApiOperation(value = "查询体检报告项目列表")
    //@RequiresPermissions("health:project:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthMedicalReportProject healthMedicalReportProject) {
        startPage();
        List<HealthMedicalReportProject> list = healthMedicalReportProjectService.selectHealthMedicalReportProjectList(healthMedicalReportProject);
        return getDataTable(list);
    }

    /**
     * 导出体检报告项目列表
     */
    @ApiOperation(value = "导出体检报告项目列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:export")
    @SysLog(title = "体检报告项目", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出体检报告项目")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthMedicalReportProject healthMedicalReportProject) {
        List<HealthMedicalReportProject> list = healthMedicalReportProjectService.selectHealthMedicalReportProjectList(healthMedicalReportProject);
        ExcelUtil<HealthMedicalReportProject> util = new ExcelUtil<HealthMedicalReportProject>(HealthMedicalReportProject.class);
        util.exportExcel(response, list, "体检报告项目数据");
    }

    /**
     * 获取体检报告项目详细信息
     */
    @ApiOperation(value = "获取体检报告项目详细信息")
    //@RequiresPermissions("health:project:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthMedicalReportProjectService.selectHealthMedicalReportProjectById(id));
    }

    /**
     * 新增体检报告项目
     */
    @ApiOperation(value = "新增体检报告项目")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:add")
    @SysLog(title = "体检报告项目", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增体检报告项目")
    @PostMapping
    public AjaxResult add(@RequestBody HealthMedicalReportProject healthMedicalReportProject) {
        try {
            return toAjax(healthMedicalReportProjectService.insertHealthMedicalReportProject(healthMedicalReportProject));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改体检报告项目
     */
    @ApiOperation(value = "修改体检报告项目")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:edit")
    @SysLog(title = "体检报告项目", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改体检报告项目")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthMedicalReportProject healthMedicalReportProject) {
        try {
            return toAjax(healthMedicalReportProjectService.updateHealthMedicalReportProject(healthMedicalReportProject));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除体检报告项目
     */
    @ApiOperation(value = "删除体检报告项目")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:remove")
    @SysLog(title = "体检报告项目", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除体检报告项目")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthMedicalReportProjectService.deleteHealthMedicalReportProjectByIds(ids));
    }
}
